@@ -53,6 +53,12 @@ FAILEDOPERATION_QRCODETEMPLATEID = 'FailedOperation.QrCodeTemplateId'
 # 员工已实名。
 FAILEDOPERATION_STAFFALREADYVERIFY = 'FailedOperation.StaffAlreadyVerify'
 
+# 无法撤销，用户已开通自动签。
+FAILEDOPERATION_USERAUTOSIGNENABLEALREADY = 'FailedOperation.UserAutoSignEnableAlready'
+
+# 无法撤销，用户未生成开通链接。
+FAILEDOPERATION_USERAUTOSIGNENABLEURLNOTEXIST = 'FailedOperation.UserAutoSignEnableUrlNotExist'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -116,7 +122,7 @@ INVALIDPARAMETER_APPROVERTYPE = 'InvalidParameter.ApproverType'
 # ApproverVerifyType参数值非法
 INVALIDPARAMETER_APPROVERVERIFYTYPE = 'InvalidParameter.ApproverVerifyType'
 
-# 当前仅支持指定上传授权书和法人认证授权, 请重新指定认证方式后发起
+# 不合法的授权方式, 请重新指定授权方式后发起
 INVALIDPARAMETER_AUTHORIZATIONTYPE = 'InvalidParameter.AuthorizationType'
 
 # 重复添加签署人。
@@ -128,6 +134,9 @@ INVALIDPARAMETER_BUSINESSLICENSE = 'InvalidParameter.BusinessLicense'
 # 撤销理由填写格式错误。
 INVALIDPARAMETER_CANCELREASON = 'InvalidParameter.CancelReason'
 
+# 证件号码错误。
+INVALIDPARAMETER_CARDNUMBER = 'InvalidParameter.CardNumber'
+
 # 证件类型错误。
 INVALIDPARAMETER_CARDTYPE = 'InvalidParameter.CardType'
 
@@ -257,6 +266,9 @@ INVALIDPARAMETER_SIGNCOMPONENTS = 'InvalidParameter.SignComponents'
 # 状态异常。
 INVALIDPARAMETER_STATUS = 'InvalidParameter.Status'
 
+# 统一社会信用代码不符合要求
+INVALIDPARAMETER_UNIFORMSOCIALCREDITCODE = 'InvalidParameter.UniformSocialCreditCode'
+
 # 参数错误，不合法的签署顺序，请检查后重试。
 INVALIDPARAMETER_UNORDERED = 'InvalidParameter.Unordered'
 
@@ -350,6 +362,9 @@ MISSINGPARAMETER_USEROPENID = 'MissingParameter.UserOpenId'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 参与人信息有重复
+OPERATIONDENIED_APPROVERREPEAT = 'OperationDenied.ApproverRepeat'
+
 # 不支持的可见性标识。
 OPERATIONDENIED_AUTHTAG = 'OperationDenied.AuthTag'
 
