@@ -463,6 +463,29 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ChannelCreatePreparedPersonalEsign(self, request):
+        """本接口（ChannelCreatePreparedPersonalEsign）用于创建导入个人印章
+
+        :param request: Request instance for ChannelCreatePreparedPersonalEsign.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreatePreparedPersonalEsignRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreatePreparedPersonalEsignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreatePreparedPersonalEsign", params, headers=headers)
+            response = json.loads(body)
+            model = models.ChannelCreatePreparedPersonalEsignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ChannelCreateReleaseFlow(self, request):
         """发起解除协议，主要应用场景为：基于一份已经签署的合同，进行解除操作。
         合同发起人必须在电子签已经进行实名。
@@ -1190,7 +1213,7 @@ class EssbasicClient(AbstractClient):
         >
         >  3：取消部分子客授权 OperateType=DELETE
         > - 对子客企业进行模板库中模板可见性的进行删除操作。
-        > - 主要对于手动领取的模板，去除授权后子客在在模板库中看不到，就无法再领取了。但是已经领取过成为自有模板的不会同步删除。
+        > - 主要对于手动领取的模板，去除授权后子客在模板库中看不到，就无法再领取了。但是已经领取过成为自有模板的不会同步删除。
         > - 对于自动领取的模板，由于已经下发，更改授权不会影响。
         > - 如果要同步删除子客自有模板库中的模板，请使用OperateType=UPDATE+Available参数处理。
 
